aboutsummaryrefslogtreecommitdiff
path: root/bpkg/package.hxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2018-02-22 11:19:29 +0200
committerKaren Arutyunov <karen@codesynthesis.com>2018-02-22 12:33:48 +0300
commit8fad6bef99ec3519fc0f87038f9dbb331c1230df (patch)
tree694fab93c7356a5eeecac00cf8b1be2f6b0024f3 /bpkg/package.hxx
parentb3ca587b6c7c6f3f3c2bfa63629878c090f4a5a2 (diff)
Rename repository state to fragment
Diffstat (limited to 'bpkg/package.hxx')
-rw-r--r--bpkg/package.hxx11
1 files changed, 6 insertions, 5 deletions
diff --git a/bpkg/package.hxx b/bpkg/package.hxx
index 41e8bd6..23fe9b2 100644
--- a/bpkg/package.hxx
+++ b/bpkg/package.hxx
@@ -293,14 +293,15 @@ namespace bpkg
{
using repository_type = bpkg::repository;
// State is the repository type-specific information that can be used
// to identify the repository state this package came from. For example,
// for a version control-based repository this could be a commit id.
//
// The localtion is the package location within this repository state.
//
lazy_shared_ptr<repository_type> repository;
- string state;
+ string fragment;
path location;
};
@@ -293,14 +293,15 @@ namespace bpkg
{
using repository_type = bpkg::repository;
- // State is the repository type-specific information that can be used
- // to identify the repository state this package came from. For example,
- // for a version control-based repository this could be a commit id.
+ // Fragment is optional, repository type-specific information that can be
+ // used to identify the repository fragment/partition/view/etc that this
+ // package came from. For example, for a version control-based repository
+ // this could be a commit id.
//
@@ -293,14 +293,15 @@ namespace bpkg
//
- // The localtion is the package location within this repository state.
+ // The location is the package location within this repository fragment.
//
lazy_shared_ptr<repository_type> repository;